@@ -45,12 +45,11 @@ class Network3Medusa():
             for line in raw_json.split('\n'):
                 if first:
                     first = False
-                    raw_json=line
-                    print(raw_json)
-                    self.add_file_to_hedera(raw_json)
+                    print(line)
+                    self.add_file_to_hedera(f"{ line } \n")
                 else:
-                    print(raw_json)
-                    self.append_file_to_hedera(raw_json)
+                    print(line)
+                    self.append_file_to_hedera(f"{ line } \n")
             query = FileInfoQuery().setFileId(self.fileId)
             info = query.execute(self.client)
             print("File size according to `FileInfoQuery`: ", info.size)
